@@ -185,12 +185,6 @@ class Q_DECL_EXPORT ShortcutTrigger
 
         QString primaryShortcut() const;
 
-    Q_SIGNALS:
-
-        //! Emitted when the global shortcut is changed from somewhere else
-        //  (Global Shortcuts KCM)
-        void globalShortcutChanged(const QKeySequence&);
-
     public Q_SLOTS:
 
         void trigger();
